==> nextcloud-28.0.8.tgz: nextcloud/apps/activity/l10n/es_AR.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Secuencia de actividad Personal para %s",
    "Your feed URL is invalid" : "Su fuente URL es inválida",
    "Activity feed" : "Secuencia de Actividad",
    "Your settings have been updated." : "Su configuración ha sido actualizada",
    "Settings have been updated." : "Las Preferencias han sido actualizadas. ",
    "Recent activity" : "Actividad reciente",
    "No activities" : "Sin actividades",
    "More activities" : "Otras actividades",
    "Daily activity summary for %s" : "Resumen de actividad diaria para... 1%s",
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por Ud.",
    "Activity at %s" : "Actividad en 1%s",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s:",
    "There was some activity at %s" : "Ha habido alguna actividad en %s",
    "_and %n more _::_and %n more _" : ["y %n mas","y %n más","y %n más"],
    "Mail" : "Correo Electrónico",
    "Push" : "Notificación Push",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite a las personas ver un registro de actividades sobre ellas, sus archivos u otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta app permite a las personas ver las acciones relacionadas con sus archivos y datos en Nextcloud. \n\t\tCada persona puede configurar sus ajustes individuales de actividad en los ajustes personales,\n\t\tpara elegir qué actividad debe ser enviada a los celulares, enviada por email\n\t\to si se envía un resumen diario cada mañana.\n\t\tMás información está disponible en la documentación de Actividad.",
    "Activity notification configuration" : "Configuración de notificaciones de actividad",
    "Send email" : "Enviar correo electrónico",
    "Send push notification" : "Enviar notificacion push",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de poder recibir las notificaciones en tu correo electrónico.",
    "Send activity emails" : "Enviar emails de actividad",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada Hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Ud. ha comentado",
    "Open {filename}" : "Abrir {filename}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "This stream will show events like additions, changes & shares" : "Este fujo mostrará eventos agregados, modificados y compartidos.",
    "No activity yet" : "Ninguna actividad aún",
    "Activity settings" : "Configuración de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Copy RSS feed link" : "Copiar enlace RSS",
    "Personal notification settings" : "Configuración de notificaciones personales",
    "Unable to load the activity list" : "No se puede cargar la lista de actividades",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar notificaciones de correo",
    "Choose for which activities you want to get an email or push notification." : "Elija para qué actividades desea recibir un correo electrónico o una notificación automática.",
    "Choose for which activities you want to get a push notification." : "Elija para qué actividades desea recibir una notificación automática.",
    "Daily activity summary" : "Resumen de actividad diaria",
    "Send daily activity summary in the morning" : "Enviar resumen de actividad diaria por la mañana",
    "Default settings" : "Configuraciónes por defecto",
    "Configure the default notification settings for new accounts." : "Configure los ajustes de notificación por defecto para las nuevas cuentas.",
    "Unable to save the settings" : "No se pudo guardar la configuración",
    "No more events to load" : "No hay más eventos para cargar",
    "Copied!" : "Copiado!",
    "Not supported!" : "No soportado!",
    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "There are no events for this filter" : "No hay eventos para este filtro"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.5.tgz: nextcloud/apps/activity/l10n/es_AR.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de su fuente es inválida",
    "Activity feed for %1$s" : "Fuente de actividad para %1$s",
    "Activity feed" : "Fuente de actividad",
    "Your settings have been updated." : "Su configuración ha sido actualizada",
    "Settings have been updated." : "Las Preferencias han sido actualizadas. ",
    "Recent activity" : "Actividad reciente",
    "No activities" : "Sin actividades",
    "More activities" : "Otras actividades",
    "Daily activity summary for %s" : "Resumen de actividad diaria para... 1%s",
    "_and %n more…_::_and %n more…_" : ["y %n más...","y %n más...","y %n más..."],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por Ud.",
    "Activity at %s" : "Actividad en 1%s",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s:",
    "There was some activity at %s" : "Ha habido alguna actividad en %s",
    "_and %n more _::_and %n more _" : ["y %n mas","y %n más","y %n más"],
    "Mail" : "Correo Electrónico",
    "Push" : "Notificación Push",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite a las personas ver un registro de actividades sobre ellas, sus archivos u otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta app permite a las personas ver las acciones relacionadas con sus archivos y datos en Nextcloud. \n\t\tCada persona puede configurar sus ajustes individuales de actividad en los ajustes personales,\n\t\tpara elegir qué actividad debe ser enviada a los celulares, enviada por email\n\t\to si se envía un resumen diario cada mañana.\n\t\tMás información está disponible en la documentación de Actividad.",
    "Activity notification configuration" : "Configuración de notificaciones de actividad",
    "Send email" : "Enviar correo electrónico",
    "Send push notification" : "Enviar notificacion push",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de poder recibir las notificaciones en tu correo electrónico.",
    "Send activity emails" : "Enviar emails de actividad",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada Hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Ud. ha comentado",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "Open {filename}" : "Abrir {filename}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "Loading activities" : "Cargando actividades",
    "This stream will show events like additions, changes & shares" : "Este fujo mostrará eventos agregados, modificados y compartidos.",
    "No activity yet" : "Ninguna actividad aún",
    "Loading more activities" : "Cargando más actividades",
    "No more activities." : "No hay más actividades.",
    "Could not load activities" : "No se pudieron cargar las actividades",
    "Activity settings" : "Configuración de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Copy RSS feed link" : "Copiar enlace RSS",
    "Personal notification settings" : "Configuración de notificaciones personales",
    "Could not enable RSS link" : "No se pudo habilitar el enlace RSS",
    "RSS link copied to clipboard" : "Enlace RSS copiado al portapapeles",
    "Could not copy the RSS link, please copy manually:" : "No se pudo copiar el enlace RSS, por favor cópielo manualmente:",
    "Unable to load the activity list" : "No se puede cargar la lista de actividades",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar notificaciones de correo",
    "Choose for which activities you want to get an email or push notification." : "Elija para qué actividades desea recibir un correo electrónico o una notificación automática.",
    "Choose for which activities you want to get a push notification." : "Elija para qué actividades desea recibir una notificación automática.",
    "Daily activity summary" : "Resumen de actividad diaria",
    "Send daily activity summary in the morning" : "Enviar resumen de actividad diaria por la mañana",
    "Default settings" : "Configuraciónes por defecto",
    "Configure the default notification settings for new accounts." : "Configure los ajustes de notificación por defecto para las nuevas cuentas.",
    "Unable to save the settings" : "No se pudo guardar la configuración",
    "No more events to load" : "No hay más eventos para cargar",
    "Could not load activites" : "No se pudieron cargar las actividades"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
